@@ -756,7 +756,7 @@ class WitterUI():
         hbox2 = gtk.HBox()
         hbox3 = gtk.HBox()
         #empty the dynamic buttons
-
+        self.controller.reply_all = ""
         #add avatar image and the tweet selected
         # then all the associated action buttons
         #standard buttons
@@ -1980,6 +1980,7 @@ class WitterUI():
         stack = hildon.WindowStack.get_default()
         stack.pop(1)
         self.show_account_window(widget)
+        self.controller.activeAccount.connect()
 
     def setActiveAccount(self, widget, selector, accList):
         selected = selector.get_current_text()
