@@ -868,25 +868,25 @@ class Witter():
                     self.ui.setActiveListStore(self.activeAccount.getTimeline())
                     self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - timeline")
                 if (curView == self.ui.MENTIONS_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getMentions())
+                    self.ui.setActiveListStore(self.activeAccount.getMentionsList())
                     self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - mentions")
                 if (curView == self.ui.DM_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getDMs())
+                    self.ui.setActiveListStore(self.activeAccount.getDmsList())
                     self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - DMs")
                 if (curView == self.ui.SEARCH_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getSearch())
+                    self.ui.setActiveListStore(self.activeAccount.getSearchList())
                     self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - search")
                 if (curView == self.ui.FRIENDS_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getFriends())
+                    self.ui.setActiveListStore(self.activeAccount.getFriendsList())
                     self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - friends")
                 if (curView == self.ui.TRENDS_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getTrends())
+                    self.ui.setActiveListStore(self.activeAccount.getTrendsList())
                     self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - trends")
                 if (curView == self.ui.PUBLIC_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getPublic())
+                    self.ui.setActiveListStore(self.activeAccount.getPublicList())
                     self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - public")
                 if (curView == self.ui.USERHIST_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getUserHistory())
+                    self.ui.setActiveListStore(self.activeAccount.getUserHistoryList())
                     self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - user history")
 
 
@@ -899,7 +899,7 @@ class Witter():
         for account in self.accounts:
             if (account.getAccountData() == accountData):
                 self.accounts.remove(account)
-        self.config.accountList.remove(account)
+                self.config.accountList.remove(account.getAccountData())
 
 
     def getVersion(self):
